@@ -1,7 +1,7 @@
 module OrdinaryDiffEqPRK
 
 import OrdinaryDiffEqCore: OrdinaryDiffEqAlgorithm, alg_order, OrdinaryDiffEqMutableCache,
-                           OrdinaryDiffEqConstantCache, constvalue, @unpack, @cache,
+                           OrdinaryDiffEqConstantCache, constvalue, @cache,
                            alg_cache, get_fsalfirstlast,
                            unwrap_alg, perform_step!, @threaded, initialize!, isthreaded,
                            full_cache, generic_solver_docstring
